==> billogram-foundation-3.13.10.tgz: package/modules/components/monthpicker/MonthpickerState.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Monthpicker from './Monthpicker';
import MonthpickerState from './MonthpickerState';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker'
});

const TestMonthpickerState = MonthpickerState({
    Component: TestMonthpicker
});

test('should set value', () => {
    const initialValue = +new Date(2000, 0, 1);
    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue } />
    );

    expect(monthpicker.state('value')).toBe(initialValue);
});

test('should change when clicking next', () => {
    const initialValue = +new Date(2000, 0, 1);
    const onChange = jest.fn();

    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue }
            onChange={ onChange } />
    );

    monthpicker.find('TestMonthpickerNextMonth').simulate('click');

    expect(monthpicker.state('value')).toBe(+new Date(2000, 1, 1));
    expect(onChange).toHaveBeenCalledWith(+new Date(2000, 1, 1));
});

test('should change when clicking next', () => {
    const initialValue = +new Date(2000, 0, 1);
    const onChange = jest.fn();

    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue }
            onChange={ onChange } />
    );

    monthpicker.find('TestMonthpickerPreviousMonth').simulate('click');

    expect(monthpicker.state('value')).toBe(+new Date(1999, 11, 1));
    expect(onChange).toHaveBeenCalledWith(+new Date(1999, 11, 1));
});

==> billogram-foundation-4.7.7.tgz: package/modules/components/monthpicker/MonthpickerState.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Monthpicker from './Monthpicker';
import MonthpickerState from './MonthpickerState';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker',
});

const TestMonthpickerState = MonthpickerState({
    Component: TestMonthpicker,
});

test('should set value', () => {
    const initialValue = +new Date(2000, 0, 1);
    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue } />
    );

    expect(monthpicker.state('value')).toBe(initialValue);
});

test('should change when clicking next', () => {
    const initialValue = +new Date(2000, 0, 1);
    const onChange = jest.fn();

    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue }
            onChange={ onChange } />
    );

    monthpicker.find('TestMonthpickerNextMonth').simulate('click');

    expect(monthpicker.state('value')).toBe(+new Date(2000, 1, 1));
    expect(onChange).toHaveBeenCalledWith(+new Date(2000, 1, 1));
});

test('should change when clicking next', () => {
    const initialValue = +new Date(2000, 0, 1);
    const onChange = jest.fn();

    const monthpicker = mount(
        <TestMonthpickerState
            initialValue={ initialValue }
            onChange={ onChange } />
    );

    monthpicker.find('TestMonthpickerPreviousMonth').simulate('click');

    expect(monthpicker.state('value')).toBe(+new Date(1999, 11, 1));
    expect(onChange).toHaveBeenCalledWith(+new Date(1999, 11, 1));
});
